# Copyright (c) 2000-2007, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%define with()          %{expand:%%{?with_%{1}:1}%%{!?with_%{1}:0}}
%define without()       %{expand:%%{?with_%{1}:0}%%{!?with_%{1}:1}}
%define bcond_with()    %{expand:%%{?_with_%{1}:%%global with_%{1} 1}}
%define bcond_without() %{expand:%%{!?_without_%{1}:%%global with_%{1} 1}}

%bcond_with gcj_support
%bcond_with maven
%bcond_with manual
%bcond_without repolib
%bcond_with sf_plugins

%define repodir %{_javadir}/repository.jboss.com/jaxen/%{version}-brew
%define repodirlib %{repodir}/lib
%define repodirsrc %{repodir}/src

%if %with gcj_support
%define gcj_support 1
%else
%define gcj_support 0
%endif

%define section free

Name:           jaxen
Version:        1.1.2
Release:        6%{?dist}
Epoch:          0
Summary:        XPath engine written in Java
License:        Open Source
Url:            http://jaxen.codehaus.org/
Group:          Development/Libraries/Java
Source0:        http://dist.codehaus.org/jaxen/distributions/jaxen-1.1.2-src.tar.gz
Source1:        pom-maven2jpp-mapdeps.xsl
Source2:        %{name}-1.1.1-jpp-depmap.xml
Source3:        %{name}-1.1.1-jpp-disable-mojo-depmap.xml
Source4:        %{name}-1.1.2-build.xml
Source5:        jaxen-1.1.2.pom
Source6:        jaxen-component-info.xml
Patch0:         jaxen-project_xml.patch
Patch1:         %{name}-1.1.1-fix-css-path.patch
Patch2:         %{name}-1.1.2-disable-mojo-plugins.patch
Requires(post): jpackage-utils >= 0:1.7.3
Requires(postun): jpackage-utils >= 0:1.7.3
Requires:       dom4j >= 0:1.6.1
Requires:       jdom >= 0:1.0-1
Requires:       xalan-j2
Requires:       xerces-j2
#Optional:       xom

BuildRequires:  jpackage-utils >= 0:1.7.3
BuildRequires:  ant >= 0:1.6.5
BuildRequires:  junit
%if %with maven
BuildRequires:  maven >= 0:1.1
BuildRequires:  saxon
BuildRequires:  saxon-scripts
BuildRequires:  maven-plugins-base >= 0:1.1
BuildRequires:  maven-plugin-changes >= 0:1.1
BuildRequires:  maven-plugin-checkstyle >= 0:1.1
BuildRequires:  maven-plugin-file-activity >= 0:1.1
BuildRequires:  maven-plugin-developer-activity >= 0:1.1
BuildRequires:  maven-plugin-jdepend >= 0:1.1
BuildRequires:  maven-plugin-jxr >= 0:1.1
BuildRequires:  maven-plugin-license >= 0:1.1
BuildRequires:  maven-plugin-linkcheck >= 0:1.1
BuildRequires:  maven-plugin-pmd >= 0:1.1
BuildRequires:  maven-plugin-tasklist >= 0:1.1
BuildRequires:  maven-plugin-test >= 0:1.1
BuildRequires:  maven-plugin-xdoc >= 0:1.1
BuildRequires:  xml-commons-jaxp-1.3-apis
%if %with sf_plugins
BuildRequires:  sf-cobertura-maven-plugin
BuildRequires:  sf-findbugs-maven-plugin
%endif
%endif
BuildRequires:  dom4j >= 0:1.6.1
BuildRequires:  jdom >= 0:1.0-1
BuildRequires:  xalan-j2
BuildRequires:  xerces-j2
BuildRequires:  xom
Provides:       jaxen-bootstrap = %{epoch}:%{version}-%{release}
Obsoletes:      jaxen-bootstrap < %{epoch}:%{version}-%{release}
%if %{gcj_support}
BuildRequires:  java-gcj-compat-devel
%else
BuildArch:      noarch
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root

%description
Jaxen is an XPath engine written in Java to work against a variety of XML
based object models such as DOM, dom4j and JDOM together with Java
Beans.
OPTIONAL: If you want to use xom as the xpath implementation make sure
xom.jar (package 'xom') is in the classpath; other xpath implementations
can also be used like the one in the JDK.

%if %with maven
%if %with manual
%package manual
Summary:        Documents for %{name}
Group:          Development/Documentation

%description manual
%{summary}.
%endif
%endif

%package demo
Summary:        Samples for %{name}
Group:          Development/Documentation
Requires:       jaxen = %{epoch}:%{version}-%{release}

%description demo
%{summary}.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Documentation

%description javadoc
%{summary}.

%if %with repolib
%package repolib
Summary:        Artifacts to be uploaded to a repository library
Group:          Development/Libraries/Java

%description repolib
Artifacts to be uploaded to a repository library.
This package is not meant to be installed but so its contents
can be extracted through rpm2cpio.
%endif

%prep
%setup -q
%{__perl} -pi -e 's/\r$//g' LICENSE.txt

cp -p %{SOURCE4} build.xml

%patch0 -b .sav0
%patch1 -b .sav1
%if %without sf_plugins
%patch2 -b .sav2
%endif

%build
%if %with maven
for p in $(find . -name project.xml); do
    pushd $(dirname $p)
    cp project.xml project.xml.orig
    %{_bindir}/saxon -o project.xml project.xml.orig %{SOURCE1} map=%{SOURCE2}
    popd
done

%if %without sf_plugins
for p in $(find . -name project.xml); do
    pushd $(dirname $p)
    cp project.xml project.xml.orig
    %{_bindir}/saxon -o project.xml project.xml.orig %{SOURCE1} map=%{SOURCE3}
    popd
done
%endif

mkdir .maven

%if %with manual
maven \
        -Dmaven.repo.remote=file:/usr/share/maven/repository \
        -Dmaven.home.local=$(pwd)/.maven \
        jar javadoc xdoc
%else
maven \
        -Dmaven.repo.remote=file:/usr/share/maven/repository \
        -Dmaven.home.local=$(pwd)/.maven \
        jar javadoc
%endif
%else
export CLASSPATH=$(build-classpath dom4j jdom xerces-j2 xml-commons-jaxp-1.3-apis xom)
export OPT_JAR_LIST=:
%{ant} jar javadoc
%endif

%install
rm -rf $RPM_BUILD_ROOT

# jars
install -d -m 0755 $RPM_BUILD_ROOT%{_javadir}
install -p -m 0644 target/%{name}-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}-%{version}.jar
%add_to_maven_depmap %{name} %{name} %{version} JPP %{name}

pushd $RPM_BUILD_ROOT%{_javadir}
for jar in *-%{version}.jar; do
        ln -sf ${jar} `echo $jar| sed "s|-%{version}\.jar|.jar|g"`;
done
popd

# poms
install -d -m 0755 $RPM_BUILD_ROOT%{_datadir}/maven2/poms
install -p -m 0644 %{SOURCE5} $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP-%{name}.pom

# javadoc
install -d -m 0755 $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}

%if %with maven
cp -pr target/docs/apidocs/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
%else
cp -pr dist/docs/api/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
%endif
ln -s %{name}-%{version} $RPM_BUILD_ROOT%{_javadocdir}/%{name}

# manual
install -d -m 755 $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}
cp -p LICENSE.txt $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}
%if %with maven
%if %with manual
cp -pr target/docs/* $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}
rm -rf $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}/apidocs/
%endif
%endif

# demo
install -d -m 755 $RPM_BUILD_ROOT%{_datadir}/%{name}-%{version}/samples
cp -pr src/java/samples/* $RPM_BUILD_ROOT%{_datadir}/%{name}-%{version}/samples

%if %with repolib
install -d -m 0755 $RPM_BUILD_ROOT%{repodir}
install -d -m 0755 $RPM_BUILD_ROOT%{repodirlib}
install -d -m 0755 $RPM_BUILD_ROOT%{repodirsrc}
%{__install} -p -m 0644 %{SOURCE6} %{buildroot}%{repodir}/component-info.xml
tag=`/bin/echo %{name}-%{version}-%{release} | %{__sed} 's|\.|_|g'`
%{__sed} -i "s/@TAG@/$tag/g" %{buildroot}%{repodir}/component-info.xml
%{__sed} -i "s/@VERSION@/%{version}-brew/g" %{buildroot}%{repodir}/component-info.xml
install -p -m 0644 %{SOURCE0} $RPM_BUILD_ROOT%{repodirsrc}
install -p -m 0644 %{SOURCE1} $RPM_BUILD_ROOT%{repodirsrc}
install -p -m 0644 %{SOURCE2} $RPM_BUILD_ROOT%{repodirsrc}
install -p -m 0644 %{SOURCE3} $RPM_BUILD_ROOT%{repodirsrc}
install -p -m 0644 %{SOURCE4} $RPM_BUILD_ROOT%{repodirsrc}
install -p -m 0644 %{SOURCE5} $RPM_BUILD_ROOT%{repodirsrc}
install -p -m 0644 %{PATCH0} $RPM_BUILD_ROOT%{repodirsrc}
install -p -m 0644 %{PATCH1} $RPM_BUILD_ROOT%{repodirsrc}
install -p -m 0644 %{PATCH2} $RPM_BUILD_ROOT%{repodirsrc}
cp -p $RPM_BUILD_ROOT%{_javadir}/jaxen.jar $RPM_BUILD_ROOT%{repodirlib}/jaxen.jar
%if %with maven
install -m 755 %{SOURCE4} $RPM_BUILD_ROOT%{repodirsrc}/
%endif
%endif

%if %{gcj_support}
%{_bindir}/aot-compile-rpm
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%post
%update_maven_depmap
%if %{gcj_support}
if [ -x %{_bindir}/rebuild-gcj-db ]
then
  %{_bindir}/rebuild-gcj-db
fi
%endif

%postun
%update_maven_depmap
%if %{gcj_support}
if [ -x %{_bindir}/rebuild-gcj-db ]
then
  %{_bindir}/rebuild-gcj-db
fi
%endif

%files
%defattr(0644,root,root,0755)
%doc %{_docdir}/%{name}-%{version}/LICENSE.txt
%{_javadir}/%{name}-%{version}.jar
%{_javadir}/%{name}.jar
%{_datadir}/maven2/poms/JPP-%{name}.pom
%{_mavendepmapfragdir}/%{name}
%if %{gcj_support}
%dir %{_libdir}/gcj/%{name}
%attr(-,root,root) %{_libdir}/gcj/%{name}/%{name}-%{version}.jar.*
%endif

%if %with maven
%if %with manual
%files manual
%defattr(0644,root,root,0755)
%{_docdir}/%{name}-%{version}
%endif
%endif

%files javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/%{name}-%{version}
%{_javadocdir}/%{name}

%files demo
%defattr(0644,root,root,0755)
%{_datadir}/%{name}-%{version}

%if %with repolib
%files repolib
%defattr(0644,root,root,0755)
%{_javadir}/repository.jboss.com
%endif

%changelog
* Thu Apr 28 2011 Fernando Nasser <fnasser@redhat.com> - 0:1.1.2-6
- Make xom optional

* Thu May 06 2010 Martha Benitez <mbenitez@redhat.com> - 0:1.1.2-4.1.1
- rebuilt

* Wed Apr 07 2010 Hui Wang <huwang@redhat.com> 0:1.1.2-4.1
- Rebuild

* Mon Aug 03 2009 David Walluck <dwalluck@redhat.com> 0:1.1.2-4
- fix pom syntax

* Mon Aug 03 2009 David Walluck <dwalluck@redhat.com> 0:1.1.2-3
- update maven pom to remove plugins

* Mon Aug 03 2009 David Walluck <dwalluck@redhat.com> 0:1.1.2-2
- add new pom
- remove saxpath depmap and symlink

* Wed Jul 29 2009 David Walluck <dwalluck@redhat.com> 0:1.1.2-1
- 1.1.2

* Fri Dec 21 2007 Ralph Apel <r.apel@r-apel.de> 0:1.1.1-1jpp
- 1.1.1
- Add pom and depmap frag

* Fri Nov 16 2007 Ralph Apel <r.apel@r-apel.de> 0:1.1-4jpp
- Provide saxpath legacy symlink

* Fri May 04 2007 Ralph Apel <r.apel@r-apel.de> 0:1.1-3jpp
- Fix project_xml.patch to meet depmap processing
- Add maven-plugin-checkstyle, -jxr, -linkcheck, -pmd BRs

* Wed Feb 21 2007 Ralph Apel <r.apel@r-apel.de> 0:1.1-2jpp
- Fix patches
- Add gcj_support option
- Drop echoing of options in prep

* Sat Feb 17 2007 Fernando Nasser <fnasser@redhat.com> - 0:1.1-1jpp
- Upgrade to 1.1 final
- Updated xsl sheet
- Updated ant build file
- Removed un-necessary saxon transforms
- Fixed BuildRequires and Requires
- Fixed javadoc creation
- Added an option to not use sf plugins

* Sun Feb 26 2006 Fernando Nasser <fnasser@redhat.com> - 0:1.1-0.b7.4jpp
- Rebuild for JPP 1.7

* Wed Feb 15 2006 Ralph Apel <r.apel@r-apel.de> 0:1.1-0.b7.3jpp
- Insert Copyright notice

* Mon Feb 13 2006 Ralph Apel <r.apel@r-apel.de> 0:1.1-0.b7.2jpp
- Adapt to maven-1.1
- Create option to build without maven

* Wed Aug 17 2005 Ralph Apel <r.apel@r-apel.de> 0:1.1-0.b7.1jpp
- Upgrade to 1.1-beta-7
- Now mavenized
- Requiring dom4j >= 1.6.1
- rpmbuild option to inhibit build of manual (needs newer maven)

* Thu Sep 09 2004 Ralph Apel <r.apel@r-apel.de> 0:1.1-0.b2.1jpp
- Upgrade to 1.1-beta-2
- Drop saxpath requirement as saxpath is now included in jaxen

* Sun Aug 23 2004 Randy Watler <rwatler at finali.com> - 0:1.0-4jpp
- Rebuild with ant-1.6.2
* Mon Jan 19 2004 Ralph Apel <r.apel@r-apel.de> 0:1.0-3jpp
- build against dom4j-1.4-1jpp
- introduce manual and demo subpackages
- patch org.jaxen.dom4j.DocumentNavigatorTest
- include LICENSE in main package
- run tests during build

* Thu Jan 15 2004 Ralph Apel <r.apel@r-apel.de> 0:1.0-2jpp
- activate support for dom4j by renaming lib/dom4j-core.jar to .zip

* Sun May 04 2003 David Walluck <david@anti-microsoft.org> 0:1.0-1jpp
- release
